@@ -47,13 +47,6 @@ where
     fn distance(&self, query_geometry: &QueryGeometry) -> T;
 }
 
-pub trait Overlaps<T, QueryGeometry>
-where
-    T: Scalar,
-{
-    fn overlaps_with(&self, query_geometry: &QueryGeometry) -> bool;
-}
-
 pub trait GeometryCollection<'a> {
     type Geometry;
 
@@ -69,18 +62,6 @@ pub trait DistanceQuery<'a, QueryGeometry>: GeometryCollection<'a> {
     fn nearest(&'a self, query_geometry: &'a QueryGeometry) -> Option<usize>;
 }
 
-pub trait NeighborhoodQuery<'a, QueryGeometry>: GeometryCollection<'a> {
-    type NeighborsIter: Iterator<Item = usize>;
-
-    fn neighbors_within_distance(&'a self, query_geometry: &'a QueryGeometry) -> Self::NeighborsIter;
-}
-
-pub trait OverlapQuery<'a, QueryGeometry>: GeometryCollection<'a> {
-    type OverlapIter: Iterator<Item = usize>;
-
-    fn overlapping_geometries(&'a self, query_geometry: &'a QueryGeometry) -> Self::OverlapIter;
-}
-
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct SignedDistanceResult<T, D>
 where
@@ -123,7 +104,6 @@ where
     D: DimName,
     DefaultAllocator: Allocator<T, D>,
     OVector<T, D>: Copy,
-    // <DefaultAllocator as Allocator<T, D>>::Buffer: Copy,
 {
 }
 
@@ -211,6 +191,19 @@ where
     pub fn contains_point(&self, point: &OPoint<T, D>) -> bool {
         (0..D::dim()).all(|dim| point[dim] > self.min[dim] && point[dim] < self.max[dim])
     }
+
+    pub fn intersects(&self, other: &Self) -> bool {
+        for i in 0 .. D::dim() {
+            if !intervals_intersect([self.min[i], self.max[i]], [other.min[i], other.max[i]]) {
+                return false
+            }
+        }
+        true
+    }
+}
+
+fn intervals_intersect<T: RealField>([l1, u1]: [T; 2], [l2, u2]: [T; 2]) -> bool {
+    l2 <= u1 && u2 >= l1
 }
 
 impl<T, D> BoundedGeometry<T> for AxisAlignedBoundingBox<T, D>
